@@ -6,7 +6,6 @@ TEMPLATES = {
     "record-service-config": "templates/invenio_record_service_config.py.jinja2",
     "record-service": "templates/invenio_record_service.py.jinja2",
     "record-schema": "templates/invenio_record_schema.py.jinja2",
-    "object-schema": "templates/invenio_record_object_schema.py.jinja2",
     "record-dumper": "templates/invenio_record_dumper.py.jinja2",
     "record-resource-config": "templates/invenio_record_resource_config.py.jinja2",
     "record-resource": "templates/invenio_record_resource.py.jinja2",
@@ -18,9 +17,6 @@ TEMPLATES = {
     "record-facets": "templates/invenio_record_facets.py.jinja2",
     # utils and included
     "imports": "templates/imports.py.jinja2",
-    # scripts
-    "script-import-sample-data": "templates/script_import_sample_data.py.jinja2",
-    "script-import-sample-data-shell": "templates/script_import_sample_data.sh.jinja2",
     # cli
     "cli": "templates/invenio_cli.py.jinja2",
 }
